==> libreoffice-still-sdk-7.1.8-3-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_14.js <==
var searchData=
[
  ['uncover_5fto_5fbottom_0',['UNCOVER_TO_BOTTOM',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da53b87cf85d7e2702d78e3561ac6fcd32',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5fleft_1',['UNCOVER_TO_LEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da7a9cf4b27313621db99e3278a642e55c',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5flowerleft_2',['UNCOVER_TO_LOWERLEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3dad094b0cba98d88463166441f1b5fc150',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5flowerright_3',['UNCOVER_TO_LOWERRIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da7fdf6ac999b5f91be21d0cb7450a14db',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5fright_4',['UNCOVER_TO_RIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da033ad93b2d55f04cc3b948ae4b6bd151',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5ftop_5',['UNCOVER_TO_TOP',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da74169a39ce46694e45e14cabf1031c84',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5fupperleft_6',['UNCOVER_TO_UPPERLEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3daa05bbd35a92d89e9f64e4bfd6af8258f',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5fupperright_7',['UNCOVER_TO_UPPERRIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da947a39fafa9e5ff9ff061d6e9636e34f',1,'com::sun::star::presentation']]],
  ['unexpected_5fnode_8',['UNEXPECTED_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dcac48fe0d9372c8ea438181197ac491d4c',1,'com::sun::star::xml::crypto']]],
  ['union_9',['UNION',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328a4cf5e96eb7880eb38df303a6e5759afd',1,'com::sun::star::uno']]],
  ['unknown_10',['UNKNOWN',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5ab6aedfcb4a10d1a01e272f492e2c2765',1,'com::sun::star::ucb::UNKNOWN()'],['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca6ce26a62afab55d7606ad4e92428b30c',1,'com::sun::star::xml::crypto::UNKNOWN()'],['../namespacecom_1_1sun_1_1star_1_1script.html#a63e3de542c5d38de617ab78c8c8f5a41a6ce26a62afab55d7606ad4e92428b30c',1,'com::sun::star::script::UNKNOWN()'],['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328a6ce26a62afab55d7606ad4e92428b30c',1,'com::sun::star::uno::UNKNOWN()']]],
  ['unlock_11',['UNLOCK',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a1f14342534859555eda67e260bd9c564',1,'com::sun::star::ucb']]],
  ['unprocessed_12',['UNPROCESSED',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a82ef3fdcd414866879e7aae1e52748d0a93c33b647b7a4b7299c25e4e6d98ef7e',1,'com::sun::star::ucb']]],
  ['unsigned_5fhyper_13',['UNSIGNED_HYPER',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328ad526b0bffd45f3dc2565846e0c85fb3f',1,'com::sun::star::uno']]],
  ['unsigned_5flong_14',['UNSIGNED_LONG',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328ae1a866a7634f747c9243826ff518edad',1,'com::sun::star::uno']]],
  ['unsigned_5fshort_15',['UNSIGNED_SHORT',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328abf575f3e209328664139bf243ab54bb6',1,'com::sun::star::uno']]],
  ['untrusted_16',['UNTRUSTED',['../namespacecom_1_1sun_1_1star_1_1security.html#abd9126083ddb902b337383198d342e9fa7665bc76e587400b5cd552744bc76f83',1,'com::sun::star::security']]],
  ['up_17',['UP',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86ab9396f8576c1edddba6173922f0812ad',1,'com::sun::star::drawing::UP()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422aba595d8bca8bc5e67c37c0a9d89becfa',1,'com::sun::star::sheet::UP()']]],
  ['upper_18',['UPPER',['../namespacecom_1_1sun_1_1star_1_1chart.html#a1391f7495aa3a95d4bc29dbf29a809eaae704d5d328a8522a6193aa3efb28c724',1,'com::sun::star::chart']]],
  ['uppercase_5flowercase_19',['UPPERCASE_LOWERCASE',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020a79de88ff4ff6d936905200303a9264b4',1,'com::sun::star::i18n']]],
  ['url_20',['URL',['../namespacecom_1_1sun_1_1star_1_1form.html#a4a4c5c07c0618f59711919741a523ab8a137e9820b1471188f4c68eba640db272',1,'com::sun::star::form::URL()'],['../namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3fa7859c6fa207d555e4f392f308b4b9d7c',1,'com::sun::star::security::URL()']]],
  ['user_21',['USER',['../namespacecom_1_1sun_1_1star_1_1view.html#a12ab04987d08416f8347a9790c7abf3eae2d30a195cee6b2961cc2c23ea4b520b',1,'com::sun::star::view']]],
  ['user_5fdefined_22',['USER_DEFINED',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4aa82bd7068d68be2a0d6f24aa8d6716f2',1,'com::sun::star::drawing']]]
];

==> libreoffice-still-sdk-7.5.9-2-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_14.js <==
var searchData=
[
  ['uncover_5fto_5fbottom_0',['UNCOVER_TO_BOTTOM',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da53b87cf85d7e2702d78e3561ac6fcd32',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5fleft_1',['UNCOVER_TO_LEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da7a9cf4b27313621db99e3278a642e55c',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5flowerleft_2',['UNCOVER_TO_LOWERLEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3dad094b0cba98d88463166441f1b5fc150',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5flowerright_3',['UNCOVER_TO_LOWERRIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da7fdf6ac999b5f91be21d0cb7450a14db',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5fright_4',['UNCOVER_TO_RIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da033ad93b2d55f04cc3b948ae4b6bd151',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5ftop_5',['UNCOVER_TO_TOP',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da74169a39ce46694e45e14cabf1031c84',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5fupperleft_6',['UNCOVER_TO_UPPERLEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3daa05bbd35a92d89e9f64e4bfd6af8258f',1,'com::sun::star::presentation']]],
  ['uncover_5fto_5fupperright_7',['UNCOVER_TO_UPPERRIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da947a39fafa9e5ff9ff061d6e9636e34f',1,'com::sun::star::presentation']]],
  ['unexpected_5fnode_8',['UNEXPECTED_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dcac48fe0d9372c8ea438181197ac491d4c',1,'com::sun::star::xml::crypto']]],
  ['union_9',['UNION',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328a4cf5e96eb7880eb38df303a6e5759afd',1,'com::sun::star::uno']]],
  ['unknown_10',['unknown',['../namespacecom_1_1sun_1_1star_1_1script.html#a63e3de542c5d38de617ab78c8c8f5a41a6ce26a62afab55d7606ad4e92428b30c',1,'com::sun::star::script::UNKNOWN'],['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328a6ce26a62afab55d7606ad4e92428b30c',1,'com::sun::star::uno::UNKNOWN'],['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5ab6aedfcb4a10d1a01e272f492e2c2765',1,'com::sun::star::ucb::UNKNOWN'],['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca6ce26a62afab55d7606ad4e92428b30c',1,'com::sun::star::xml::crypto::UNKNOWN']]],
  ['unlock_11',['UNLOCK',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a1f14342534859555eda67e260bd9c564',1,'com::sun::star::ucb']]],
  ['unprocessed_12',['UNPROCESSED',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a82ef3fdcd414866879e7aae1e52748d0a93c33b647b7a4b7299c25e4e6d98ef7e',1,'com::sun::star::ucb']]],
  ['unsigned_5fhyper_13',['UNSIGNED_HYPER',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328ad526b0bffd45f3dc2565846e0c85fb3f',1,'com::sun::star::uno']]],
  ['unsigned_5flong_14',['UNSIGNED_LONG',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328ae1a866a7634f747c9243826ff518edad',1,'com::sun::star::uno']]],
  ['unsigned_5fshort_15',['UNSIGNED_SHORT',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328abf575f3e209328664139bf243ab54bb6',1,'com::sun::star::uno']]],
  ['untrusted_16',['UNTRUSTED',['../namespacecom_1_1sun_1_1star_1_1security.html#abd9126083ddb902b337383198d342e9fa7665bc76e587400b5cd552744bc76f83',1,'com::sun::star::security']]],
  ['up_17',['up',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86ab9396f8576c1edddba6173922f0812ad',1,'com::sun::star::drawing::UP'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422aba595d8bca8bc5e67c37c0a9d89becfa',1,'com::sun::star::sheet::UP']]],
  ['upper_18',['UPPER',['../namespacecom_1_1sun_1_1star_1_1chart.html#a1391f7495aa3a95d4bc29dbf29a809eaae704d5d328a8522a6193aa3efb28c724',1,'com::sun::star::chart']]],
  ['uppercase_5flowercase_19',['UPPERCASE_LOWERCASE',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020a79de88ff4ff6d936905200303a9264b4',1,'com::sun::star::i18n']]],
  ['url_20',['url',['../namespacecom_1_1sun_1_1star_1_1form.html#a4a4c5c07c0618f59711919741a523ab8a137e9820b1471188f4c68eba640db272',1,'com::sun::star::form::URL'],['../namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3fa7859c6fa207d555e4f392f308b4b9d7c',1,'com::sun::star::security::URL']]],
  ['user_21',['USER',['../namespacecom_1_1sun_1_1star_1_1view.html#a12ab04987d08416f8347a9790c7abf3eae2d30a195cee6b2961cc2c23ea4b520b',1,'com::sun::star::view']]],
  ['user_5fdefined_22',['USER_DEFINED',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4aa82bd7068d68be2a0d6f24aa8d6716f2',1,'com::sun::star::drawing']]]
];
